# 接入消息平台

AstrBot 支持接入众多主流即时通讯软件平台，帮助您在自己喜欢的 IM 平台上使用 AstrBot 的强大功能。

在 WebUI 中，点击侧边栏的**机器人**，即可进入消息平台接入界面。点击右上角的**创建机器人**，选择您想要接入的平台，按照本文档左侧提供的接入指南进行操作，即可完成接入。

> [!TIP]
> 建议在部署前预先安装 `ffmpeg`（并确保支持 `amr`），否则媒体类文件可能无法正常收发。对于微信类平台接入，强烈建议安装。